// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
import { ServerConnection } from '@jupyterlab/services';
/**
 * Make a client-side request to the GitHub API.
 *
 * @param url - the api path for the GitHub API v3
 *   (not including the base url).
 *
 * @returns a Promise resolved with the JSON response.
 */
export function browserApiRequest(url) {
    return window.fetch(url).then(response => {
        if (response.status !== 200) {
            return response.json().then(data => {
                throw new ServerConnection.ResponseError(response, data.message);
            });
        }
        return response.json();
    });
}
/**
 * Make a request to the notebook server proxy for the
 * GitHub API.
 *
 * @param url - the api path for the GitHub API v3
 *   (not including the base url)
 *
 * @param settings - the settings for the current notebook server.
 *
 * @returns a Promise resolved with the JSON response.
 */
export function proxiedApiRequest(url, settings) {
    return ServerConnection.makeRequest(url, {}, settings).then(response => {
        if (response.status !== 200) {
            return response.json().then(data => {
                throw new ServerConnection.ResponseError(response, data.message);
            });
        }
        return response.json();
    });
}
